# -*- coding: utf8 -*-

import hashlib
import random
import subprocess

from django.db import models

from django.template import loader, Context 
from django.conf import settings

from django.utils.translation import ugettext
from django.utils.translation import ugettext_lazy as _
from django.core.mail import send_mail

from ckeditor.fields import RichTextField


class Subscriber(models.Model) :
    email = models.EmailField(unique = True)   # TODO : informer si déjà inscrit ? Que faire dans ce cas.
    inscription_date = models.DateField(auto_now_add=True)
    is_validated = models.NullBooleanField() # Au click sur le lien de confirmation. Null si erreur à l'envoi au souscripteur.
    is_registered = models.NullBooleanField() # À l'inscription après la confirmation Null si erreur à l'envoi à mailman.
    password = models.CharField(max_length=100) # sha1
    
    def __unicode__(self) :
        return self.email

    def save(self, *args, **kwargs):
        super(Subscriber, self).save(*args, **kwargs)
        if self.is_validated is None:
            self.send_confirmation_email()

    def send_confirmation_email(self):
        self.password = hashlib.sha1(str(random.random())).hexdigest()
        confirm_subject = loader.get_template('newsletter/confirmation_email_subject.txt')
        confirm_body = loader.get_template('newsletter/confirmation_email_body.txt')
        context = Context({'token': self.password})
        send_mail(confirm_subject.render(context).strip(), confirm_body.render(context),
                settings.NEWSLETTER_SENDER, [self.email])
        self.is_validated = False
        self.save()

    def subscribe_in_mailman(self):
        t = subprocess.call(['listadmin', '--add-member', self.email, settings.NEWSLETTER_NAME])
        if t != 0:
            return
        self.is_registered = True
        self.save()


class Newsletter(models.Model):

    class Meta:
        verbose_name = _('Newsletter')
        verbose_name_plural = _('Newsletters')
        ordering = ['date']

    subject = models.CharField(_('Title'), max_length=50)
    date = models.DateField(_('Date'))
    text = RichTextField(_('Text'), null=True, blank=True)

    expedition_datetime = models.DateTimeField(_('Expedition Date/time'), null=True, blank=True)
